# Speculos documentation

[Source code](https://github.com/LedgerHQ/speculos).

## Users

### Installation and basic usage

- Linux users: [Requirements and build](installation/build.md)
- Mac OS (and Linux) users: [How to use the Docker image](user/docker.md) with VNC
- Mac M1 users: [How to build and use the Docker image](user/macm1.md)
- Windows users: [Using speculos from WSL 2](installation/wsl.md)
- [Usage](user/usage.md)

### Interaction with an app

- [How to send APDUs to an app (and more)](user/clients.md)
- [How to use gdb to debug an app](user/debug.md)
- [How to automate actions thanks to the REST API](user/api.md)

### For advanced users

- [Automation: press buttons automatically](user/automation.md)
- [Semihosting as an additional debug mechanism](user/semihosting.md)


## Speculos developers

- [CI (Continuous Integration)](dev/ci.md)
- [Internals](dev/internals.md)
- [How to run tests](dev/tests.md)
